Package: comapr
Title: Crossover analysis and genetic map construction
Version: 1.16.0
Authors@R: 
    person(given = "Ruqian",
           family = "Lyu",
           role = c("aut", "cre"),
           email = "xiaoru.best@gmail.com",
           comment = c(ORCID = "0000-0002-7736-6612"))
Description: comapr detects crossover intervals for single gametes from their 
    haplotype states sequences and stores the crossovers in GRanges object.
    The genetic distances can then be calculated via the mapping functions 
    using estimated crossover rates for maker intervals. Visualisation functions 
    for plotting interval-based genetic map or cumulative genetic distances are 
    implemented, which help reveal the variation of crossovers landscapes across 
    the genome and across individuals. 
biocViews: Software, SingleCell, Visualization, Genetics
Depends: R (>= 4.1.0)
Imports: methods, ggplot2, reshape2, dplyr, gridExtra, plotly,
        circlize, rlang, GenomicRanges, IRanges, foreach, BiocParallel,
        GenomeInfoDb, scales, RColorBrewer, tidyr, S4Vectors, utils,
        Matrix, grid, stats, SummarizedExperiment, plyr, Gviz
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: false
RoxygenNote: 7.2.3
VignetteBuilder: knitr
Suggests: BiocStyle, knitr, rmarkdown, testthat (>= 2.1.0), statmod
git_url: https://git.bioconductor.org/packages/comapr
git_branch: RELEASE_3_23
git_last_commit: 468442a
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 21:22:13 UTC; biocbuild
Author: Ruqian Lyu [aut, cre] (ORCID: <https://orcid.org/0000-0002-7736-6612>)
Maintainer: Ruqian Lyu <xiaoru.best@gmail.com>
