
#' \code{comapr} package
#'
#' crossover inference package
#'
#' See the README on
#'  \href{https://gitlab.svi.edu.au/biocellgen-private/comapr}{GitLab}
#'
#' @docType package
#' @name comapr

NULL

if(getRversion() >= "2.15.1") utils::globalVariables(c("."))
